(*
 * <COPYRIGHT>
 * Copyright 2005 Gerd Stolpmann
 *
 * <GPL>
 * This file is part of UMLMON.
 *
 * UMLMON is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * UMLMON is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with UMLMON; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * </>
 *)

(* $Id: umlmon_common.mli 187 2005-10-14 10:54:15Z gerd $ *)

open Umlmon_types

val has_dups : 'a list -> bool
  (* Returns [true] when the list has duplicate elements *)

val restart : ('a -> 'b) -> 'a -> 'b
  (* [restart f arg] applies [f] with argument [arg], and catches EINTR conditions
   * of the operating system.
   *)

val monitor_log : string -> unit
  (* Outputs a message in the monitor log file *)

val fd_log : ?nl:bool -> Unix.file_descr -> string -> unit
  (* Outputs a message in an arbitrary file. If [nl], the message is prepended with
   * a newline character.
   *)

val open_log_file : umlspec -> string -> Unix.file_descr
  (* Open a logfile with the passed name for the user of the UML instance.
   * Returns the file descriptor.
   *)

val reopen_stderr : umlspec -> unit
  (* Opens stderr as the monitor log files *)

val protect : (Rpc_server.session -> 'b -> 'c -> unit) -> Rpc_server.session -> 'b -> 'c -> unit
  (* [protect f proc session arg reply] calls the function [f] with the other
   * values as arguments. Catches exceptions and handles them appropriately.
   *)

val string_of_unix_error : exn -> string
  (* Returns a [Unix_error] as string *)

val user_privileges : string -> string option -> privileges
  (* Returns the privileges for the passed user, and the optional group.
   * If the group is not given, the default group of the user is taken.
   * If the group is passed, the user must be member of the group.
   *)

val file_access : string -> privileges -> bool * bool * bool
  (* Returns the effective access permissions for the file and the
   * privileges. The returned triple is (r_ok, w_ok, x_ok).
   *)

val format_hwaddr : hwaddr -> string
  (* Returns a six-byte MAC address as colon-separated string *)

val parse_hwaddr : string -> hwaddr
  (* Converts a colon-separated string into a six-byte MAC address *)

val increment_hwaddr : hwaddr -> hwaddr
  (* Generates the next hwaddr *)

val rpc_over_inet : Rpc_server.session -> bool
  (* Returns [true] whether the session is Internet-based *)

val daemon : ?wait:bool -> string -> (unit -> unit) -> unit
  (* Run f() as a daemon, without controlling terminal. Note that all terminals
   * must be opened with O_NOCTTY to prevent them from becoming controlling terminals!
   *
   * [wait]: if true, wait until the daemon terminates.
   *)
